/*
 *
 *
 *   risterm.cc
 *
 *   Copyright (C) 2003, by the Grand River Dam Authority,
 *   All rights reserved.
 *
 *   Author: Matt Roberts
 *
 *
 */


#include <string>
#include <exception>
#include <iostream>

#include "rtwin.h"
#include "termapp.h"
#include "util.h"


/*
 *
 *   main (...)
 *
 */

int main (int argc, char **argv) {
	if (argc < 2) {
		std::cerr << "Must specify socket pathname." << std::endl;
		return 1;
	}

	std::string remote_address(getsockpath(argv[1]));
	std::string tty_device("/dev/tty");

	try {
		// window object
		RISTerminalWindow win_obj;

		// application object
		TerminalApplication app(tty_device, win_obj);

		// set console codes
		win_obj.setAlarmCode(COLOR_RED);
		win_obj.setNormalCode(COLOR_WHITE);

		// run the application
		return app.run(remote_address);

	} catch (const std::exception &e) {
		std::cerr << "Error: " << e.what() << std::endl;
		return 0;
	}
}

// EOF
