/*
 *
 *
 *   signals.cc
 *
 *   Copyright (C) 2003, by the Grand River Dam Authority,
 *   All rights reserved.
 *
 *   Author: Matt Roberts
 *
 *
 */



// system headers
#include <signal.h>
#include <stdlib.h>

static size_t sig_hup  = 0;
static size_t sig_int  = 0;
static size_t sig_term = 0;

void (*cleanup_handler_ptr)(int signo) = 0;


/*
 *
 *   signal_handler()
 *
 */

void signal_handler(int signo) {
	switch (signo) {
		case SIGINT: ++sig_int; break;
		case SIGHUP: ++sig_hup; break;
		case SIGTERM: ++sig_term; break;
		default: break;
	}

	if (cleanup_handler_ptr)
		cleanup_handler_ptr(signo);
}

void setup_signals (void) {
	// setup signal handling
	signal(SIGINT,  signal_handler);
	signal(SIGHUP,  signal_handler);
	signal(SIGTERM, signal_handler);
}

size_t signal_count(int signum) {
	switch (signum) {
		case SIGINT: return sig_int;
		case SIGHUP: return sig_hup;
		case SIGTERM: return sig_term;
		default: return 0;
	}
}

// EOF
